@@ -144,6 +144,9 @@ model.average <- function (..., realnames = NULL, betanames = NULL,
                     beta.vcv = object1$beta.vcv, field = x,
                     smoothsetup = object1$smoothsetup[[x]])
             }
+            ## check added 2016-06-16
+            if (nclusters(object1$capthist)>1)
+                warning("model.average is ignoring n.mashed", call. = FALSE)
             sapply (names(object1$model), getfield, simplify = FALSE)
         }
         predicted <- lapply (object, getLP)
@@ -299,6 +302,9 @@ collate <- function (..., realnames = NULL, betanames = NULL, newdata = NULL,
                 beta.vcv = object1$beta.vcv, field = x,
                 smoothsetup = object1$smoothsetup[[x]])
         }
+        ## check added 2016-06-16
+        if (nclusters(object1$capthist)>1)
+            warning("collate is ignoring n.mashed", call. = FALSE)
         sapply (names(object1$model), getfield, simplify = FALSE)
     }
 
